PoolConfig {

-- The "volatile" property is used to prevent the variable from being
-- saved in the current state.  Voltile is the opposite of persistent.
-- This always must be used when the variable represents an external
-- physical condition, such as the AES/EBU SRC lock.  Here ACMRP has
-- no control over the variable, it must always follow the real thing,
-- not what we might save.  It is also used when it is necessary to
-- track the state of other software (this is kludgey, but it may be
-- best to use ACMRP for communications even though it doesn't maintain
-- the state).  An example of this is "livewire_enable".  Finally,
-- it is used for factory calibration constants.  These are marked volatile
-- and not listed in any storage class.  This means they will never be
-- saved anywhere and will always take on the values specified as
-- defaults in this file.

-- last_selected_preset may go away, leaving only float values
-- in the VarPool.  Right now, you can't get at it from the C acmrp_client
-- API.  I keep it in here for convenience in implementing the preset
-- selection stuff in the base_server.
-- This has the string value of the last preset selected by any client
-- It does not mean that the values of all variable will equal those
-- of this preset, because they may have been changed since the last
-- preset selection.
-- You can't change presets by writing to this; you must use the 
-- loadstorage command.  It is not readonly because the storage
-- handler needs to write to it.
   last_selected_preset = { value = "<none>" },
   last_selected_iocfg = { value = "<none>" },

-- You can't change the protection group by writing to this -- must
-- use save command with the pgroup parameter.  This is for reporting
-- the active protection group.
   preset_protection_group = { value = "<none>" },
   preset_protection_mode = { value = "" },

-- Overall processing bypass.  Just set this one variable and all
-- processing will be bypassed while the signal continues to be
-- routed through the DSP's.
   overall_proc_bypass = { val_list = { 0, 1 }, value = 0 },
   -- enumerated: 0 = normal, 1 = bypass processing

-- Livewire Enable
   livewire_enable = { val_list = { 0, 1 }, value = 0 },
   -- Made non-volatile becaue IOB needs correct value before FP comes up.
   -- Moreover, there is nothing keeping this variable slaved to the 
   -- lwrp state, so the best we can do for now is to save it independently.

-- For reporting the LiveWire sync status of the IOB.  These are updated
-- not more than a few times a second.
-- Note that these actually could apply to any ONE, not just the IOB, so
-- are misnamed.
   IOB_lwsync_mast = { val_list = { 0, 1 }, value = 0, volatile = true },
   IOB_lwsync_diff = { min = -1536, max = 1536, value = 0, volatile = true },

-- For reporting the link status of the external ethernet switch ports.
-- These are updated when the link status changes.
   O11IO_port2_link = { val_list = { 0, 1 }, value = 0, volatile = true },
   O11IO_port3_link = { val_list = { 0, 1 }, value = 0, volatile = true },

   enet_port2_mode = { val_list = { 0, 1, 2 }, value = 0 },
   -- enumerated: 0=LAN only, 1=normal LW, 2=expansion mode

   patch_mode = { val_list = { 0, 1}, value = 0 },
   -- enumerated: 0=normal processing, 1=insert patch

-- FP AutoLock Enable.  This variable determines if
-- the front panel is automatically locked when the 
-- backlight is turnded off.
   fp_auto_lock = { val_list = { 0, 1 }, value = 0 },
   -- enumerated: 0 = disabled, 1 = enabled

-- Input 
   in_source = { val_list = { 1, 2, 3, 4 }, value = 1 },
   -- enumerated: 1=analog, 2=AES, 3=LiveWire, 4=LiveWire2
   in_patch_src = { val_list = { 1, 2, 3, 4 }, value = 1 },
   -- enumerated: 1=analog, 2=AES, 3=LiveWire, 4=LiveWire2
   in_failover_src = { val_list = { 1, 2, 3, 4 }, value = 1 },
   -- enumerated: 1=analog, 2=AES, 3=LiveWire, 4=Livewire2
   in_failover_time = { min = 0.0, max = 255, value = 0 }, -- seconds
   in_failback_time = { min = 0.5, max = 255, value = 1 }, -- seconds
   in_failover_abs_lvl = { min = -1000, max = 0, value = -50 }, --dBFS
   in_failover_rel_lvl = { min = -144, max = 0, value = -20 }, 
   -- dB ref. secondary signal (how far primary must be below secondary to 
   -- trigger failover logic).
   in_failover_state = { val_list = { 0, 1 }, volatile = true, value = 0 },
   -- enumerated: 0 = normal op, 1 = use failover input
   in_aes_src_lock = { val_list = { 0, 1 }, volatile = true, value = 0 },
   -- enumerated: 0 = sample rate converter PLL unlocked, 1 = locked


   in_ana_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_ana_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   in_aes_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_aes_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   APS_patchin_cal = { min = -1000.0, max = 6.0, value = -30 }, -- dB


   in_lwr_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_lwr_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   in_lwr2_mast = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   in_lwr2_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB
   O11_in_invert = { val_list = { 0, 1, 2, 3 }, value = 0 },
   --enumerated: 0 = normal, 1 = invert both, 2 = invert L only, 3 = R only
   --in_mtx_LL = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   --in_mtx_LR = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   --in_mtx_RL = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   --in_mtx_RR = { min = -1.0, max = 1.0, value = 1.0}, -- linear mix coef.
   -- Can't use the above from the front panel right now
   O11_in_stereo_mode = { val_list = { 0, 1, 2, 3, 4 }, value = 0 },
   --enumerated 0 = stereo, 1 = mono L, 2 = mono R, 3 = L+R, 4 = swap

-- Output
   O11hdfm_out_ana_select = { val_list = { 0, 1, 2}, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor
   O11hdfm_out_aes1_select = { val_list = { 0, 1, 2}, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor
   O11hdfm_out_aes2_select = { val_list = { 0, 1, 2}, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor
   O11hdfm_out_hph_select = { val_list = { 0, 1, 2}, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send
   O11hdfm_out_lwr1_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor, 3 = Patch Send
   O11hdfm_out_lwr2_select = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0 = FM, 1 = HD, 2 = Monitor

   O11hdfm_out_hd_pol = { val_list = { -1, 1 }, value = 1 },
   -- -1 to invert polarity relative to FM signal

   O11_out_ana_mast = { min = -1000, max = 22, value = 4 }, -- dBu "peak"
   out_ana_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_ana_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_aes_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes2_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_aes2_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes2_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_lwr_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr2_mast = { min = -1000.0, max = 0.0, value = -12.0 }, -- dBFS peak
   out_lwr2_L = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_lwr2_R = { min = -1000.0, max = 6.0, value = 0.0 }, -- dB ref mast
   out_aes_srate = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0=int 48k, 1=sync to input, 2=sync to ext, 3=44.1k
   out_aes2_srate = { val_list = { 0, 1, 2, 3 }, value = 0 },
   -- enumerated: 0=int 48k, 1=sync to input, 2=sync to ext, 3=44.1k

   out_div_delay_time = { min = 0, max = 30, value = 0 }, -- seconds
   out_div_delay_off = { val_list = { 0, 1 }, value = 0 },  

   O11_de_emphasis_ana={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_aes={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_aes2={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_lw={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_lw2={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_hph={ val_list = { 0, 1 }, value = 1 }, --unitless
   --  1 = on, 0 = off
   O11_de_emphasis_doro={ val_list = { 0, 1 }, value = 1 }, --enumerated
   --  1 = on, 0 = off
   APS_patchout_cal = { min = -1000, max =40, value = -12}, --dB

-- BS-412   
   bs412_engage={ val_list = { 0, 1 }, value = 0 }, --unitless
   --  1 = on, 0 = off
   bs412_main_thresh={ min = -3.0, max =9.0, value = 0}, --dB
   bs412_drive = { min = -1000, max = 12, value = 0 }, --dB
   bs412_out_cal = { min = -1000, max = 12, value = -1, volatile=true }, --dB
   bs412_hold = {min = -1000, max = 100, value = 4, volatile=true }, -- dB
   bs412_pkcomp = {min = -100, max = 0, value = 1.5, volatile=true }, -- dB
   bs412_pkcal = {min = -100, max = 50, value = 5, volatile=true }, -- dB

   O11_pre_emphasis={ val_list = { 0, 50, 75 }, value = 75 }, --us
      
   comp_out_lvl = { min = 0, max = 10, value = 5 }, --V
   comp_out_lvl_2 = { min = 0, max = 10, value = 5 }, --V
   sg_pilot_lvl = { min = 0, max = 0.12, value = 0 }, --frac of modulation
   sg_lmr_gain = { min = -1000, max = 6, value = 0 }, --dB
   -- lmr = L - R (separation control).
   ssbsg_pilot_phase ={ min = -180, max = 180,value = 0},--deg
   -- With the new SB SG, this expresses the phase of the pilot relative
   -- to the 38k carrier in degrees @ 19kHz.  Previously, it gave the
   -- phase of the 38k relative to the 19k in degrees @ 38k.  The new
   -- semantics require a name change.
   ssbsg_usb_suppression = { min = 0, max = 1, value = 0 },
   -- 0 gives DSB-SC 1 gives SSB (lower sideband) modulation
--   ssbsg_comp_clip_thresh = { min = -24, max = 0, value = -12 }, --dBFS
   ssbsg_clip_factor_one = { min = 0, max = 1, value = 0.32, volatile=true },
   ssbsg_clip_factor_two = { min = 0, max = 1, value = 0.57, volatile=true },
   -- multiplied by 8 in DSP
   O11_sg_input_calib = { min=-1000, max=6, value=1.1, volatile=true }, --dB
   O11_sg_comp_clip_drive = { min = -1000, max = 6, value = 0 }, --dB


-- I am putting all the APS stuff right in this file for now.
-- We'll figure out how best to factor it out later.



-- IO levels

   APS_mas_drive = { min = -1000, max = 18, value = 0 }, -- dB
   APS_mas_rt = { min = -1000, max = 18, value = 0 }, -- dB

-- Input filtering
   APS_hpf_filter_freq = { min = 0, max = 20000, value = 0 },
   -- currently implemented values are OUT, 20, 30, 40 and 70 Hz

--Phase Rotator
   APS_phase_rot_style = { val_list = { 0, 1, 2, 3 },
   		       	   value = 0 },
   -- 0 = none, 1 = hybrid, 2 = fully tunable, 3 = standard
   -- ACMRP_client lib does not support communication of string value
   -- variables to the client, and I'm not sure we want to add this.
   APS_phase_rot_freq = { min = 0, max = 10000, value = 200, volatile=true},
    --Hz
   APS_phase_rot_freq1 = { min = 0, max = 10000, value = 200, volatile=true },
    --Hz
   APS_phase_rot_freq2 = { min = 0, max = 10000, value = 200, volatile=true }, 
   --Hz
   APS_phase_rot_freq3 = { min = 0, max = 10000, value = 200, volatile=true },
   --Hz
   APS_phase_rot_freq4 = { min = 0, max = 10000, value = 2600, volatile=true },
    --Hz
   APS_phase_rot_freq5 = { min = 0, max = 10000, value = 2600, volatile=true },
    --Hz
   APS_phase_rot_freq6 = { min = 0, max = 10000, value = 0, volatile=true },
    --Hz
   APS_phase_rot_freq7 = { min = 0, max = 10000, value = 0, volatile=true },
    --Hz



---------------------------- wideband AGC --------------------------------
   APS_wbagc_engage = { val_list = { 0, 1 }, value = 0 },
   -- 0 = wbagc bypassed, 1 = wbagc engaged
   APS_wbagc_drive = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

--[[
   -- In the DSP:
   -- "APS_wbagc_att" is 
   -- the "base" value attack input into a standard first order,
   -- exponential att/rel.  There is an acceleration automatically applied
   -- to this attack when the audio exceeds 
   -- a secondary threshold (attack2_thresh, below)
   -- "APS_wbagc_att_lf_cal" and "APS_wbagc_att_hf_cal": 
   -- These two multiply the the attack value before it is applied to 
   -- the time constants.
   -- As it is currently implemented, the "cal" parameters are very small
   -- corresponding to the coefficients needed to realize the long
   -- RC-equiv TC's.  the "att" is a multiplier used to scale both.
   -- So, we can do it this way:
--]]
--[[
   APS_wbagc_att_mult = { min = 1/1024, max = 1024, value = 1 }, -- unitless
   APS_wbagc_att_lf_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   -- RC-equivalent TC
   APS_wbagc_att_hf_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   -- RC-equivalent TC
--]]

   -- Alternately, we could make the "att" the actual TC value
   -- and the "cal" into multipliers:
   APS_wbagc_attack = { min = 0, max = 174760, value = 5000 }, -- ms
   APS_wbagc_att_lf_cal = { min = 1/1024, max = 1024, value = 1 }, -- unitless
   APS_wbagc_att_hf_cal = { min = 1/1024, max = 1024, value = 1 }, -- unitless
   -- Looking at the DSP code, these two should be equivalent.  However,
   -- there are constructs that could make them not so (e.g. using a linear
   -- smoothing TC instead of exponential on the release switching).


--[[
   The release works similarly to the attack.  But, instead of having an
   acceleration function, the release may be switched to a release2 or
   to a window release under certain conditions.  These are both specified
   as multipliers to the main release (affecting both sidechain bands).
--]]
   APS_wbagc_release = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_wbagc_rel2_mult = { min = 1/1024, max = 1024, value = 2 }, -- unitless
   APS_wbagc_win_rel_mult = { min = 0, max = 1024, value = 0.000001 },
    -- unitless
   APS_wbagc_rel_lf_cal = { min = 0, max = 10, value = 1}, -- unitless
   APS_wbagc_rel_hf_cal = { min = 0, max = 10, value = 1 }, -- unitless

   -- Thresholds:  the "off"sets are specified relative to the main thresh
   APS_wbagc_main_thresh = { min = -1000.0, max = 0.0, value = -3 }, -- dBr1
   APS_wbagc_lf_thresh_off = { min = -1000.0, max = 12.0, value = 3.5 }, -- dB
   APS_wbagc_att2_thresh_off = {min = -1000.0, max = 40.0, value = 25}, -- dB

   APS_wbagc_glock_thresh = { min = -1000.0, max = 0.0, value = 0.0 }, -- dBr1
   -- gain lock threshold

   APS_wbagc_window = { min = -1000, max = 1000, value = -5.0 }, --dBr1
   APS_wbagc_window_cal = { min = -1000, max = 1000, value = 20 }, --dB

   APS_wbagc_inv_ratio = { min = 0, max = 1, value = 1/10 },
   -- unitless; this is the reciprocal of the ave compression ratio.
   -- For example, for a 10:1 ratio, set this to 0.1.  0.0 should give
   -- an infinity:1 ratio, but this may not be achieveable in the WBAGC.

   APS_wbagc_sidechain_gain = { min = -1000, max = 30, value = 20 }, --dB
   -- This is called "loop_gain" in the DSP, but it is not actually inside
   -- the feedback loop, so I call it sidechain gain.

   APS_wbagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   APS_wbagc_rtp_speed = { min = 0, max = 174760, value = 10000 }, -- ms
   -- This is just another exponential attack TC, we specify it same as others

   APS_wbagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   APS_wbagc_ref_off = { min = 0, max = 1, value = 0.6 }, --unitless
   APS_wbagc_gate_cal = { min = 0, max = 35, value = 10 }, --dB

   APS_wbagc_att2_react = { min = 0.000001, max = 1, value = 0.0 }, --unitless
   APS_wbagc_att2_dur = { min = 0.000001, max = 1, value = 0.0 }, --unitless

   APS_wbagc_raccel = { min = 0.000001, max = 1, value = 0.0001 }, -- unitless
   APS_wbagc_rdecel = { min = 0.000001, max = 1, value = 0.0009 }, -- unitless

   APS_wbagc_bypgain ={ min = -1000.0, max = 100.0, value = 40, volatile=true},
    --dB

   APS_wbagc_gbg = { min = 0, max = 100, value = 0.01 }, -- unitless

----------------------------------end wbagc-----------------------------------

----------------------------------mbagc crossovers----------------------------

   APS_loagc_xovr= { val_list = { 1, 2 },
   		       	   value = 1 },
   -- 1 = 190Hz, 2 = 150Hz

   APS_mlagc_xovr = { val_list = { 1, 2 },
   		       	   value = 1 },
   --  1 = 3.2 kHz, 2 = 2.5 kHz

   APS_mbagc_sync_mode = { val_list = { 0, 1 },
   		       	   value = 0 },
   --  1 = band 3 ref, 0 = band 2 ref

   APS_mbagc_engage= { val_list = { 0, 1 },
   		       	   value = 1 },
  --  1 = engage, 0 = bypass


----------------------------------mbagc---------------------------------------

-- Mix And Drives

   APS_mbagc_drive = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   APS_mbagc_drivecal = { min = -1000.0, max = 100.0, value = -25 }, -- dB	

   APS_shagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hiagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hiagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mhagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mlagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_loagc_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   APS_shagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hiagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mhagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mlagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_loagc_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

-- Output Calibration

   APS_shagc_outc = { min = -1000.0, max = 50.0, value = 0.0, volatile=true }, 
   -- dB
   APS_hiagc_outc = { min = -1000.0, max = 50.0, value = 0.0, volatile=true },
   -- dB
   APS_mhagc_outc = { min = -1000.0, max = 50.0, value = 0.5, volatile=true }, 
   -- dB
   APS_mlagc_outc = { min = -1000.0, max = 50.0, value = 1.5, volatile=true }, 
   -- dB
   APS_loagc_outc = { min = -1000.0, max = 50.0, value = 2.5, volatile=true }, 
   -- dB

   APS_mbagc_out_cal = { min = -1000.0, max = 50.0, value = 0.0 }, -- dB

--ratios

   APS_shagc_ratio = { min = -256, max = -0.000001, value = -100 }, --loop gain
   APS_hiagc_ratio = { min = -256, max = -0.000001, value = -100 }, --loop gain
   APS_mhagc_ratio = { min = -256, max = -0.000001, value = -100 }, --loop gain
   APS_mlagc_ratio = { min = -256, max = -0.000001, value = -100 }, --loop gain
   APS_loagc_ratio = { min = -256, max = -0.000001, value = -100 }, --loop gain

--Sidechain Gains
 
   APS_shagc_scg = { min = -1000.0, max = 50.0, value = 20.0 }, -- dB
   APS_hiagc_scg = { min = -1000.0, max = 50.0, value = 20.0 }, -- dB
   APS_mhagc_scg = { min = -1000.0, max = 50.0, value = 20.0 }, -- dB
   APS_mlagc_scg = { min = -1000.0, max = 50.0, value = 20.0 }, -- dB
   APS_loagc_scg = { min = -1000.0, max = 50.0, value = 20.0 }, -- dB

---multiband RTP

   APS_shagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   APS_shagc_rtp_speed = { min = 0, max = 174760, value = 10000 }, -- ms

   APS_hiagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   APS_hiagc_rtp_speed = { min = 0, max = 174760, value = 10000 }, -- ms

   APS_mhagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   APS_mhagc_rtp_speed = { min = 0, max = 174760, value = 10000 }, -- ms

   APS_mlagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   APS_mlagc_rtp_speed = { min = 0, max = 174760, value = 10000 }, -- ms

   APS_loagc_rtp_level = { min = -120, max = 0, value = -10 }, --dBGR
   APS_loagc_rtp_speed = { min = 0, max = 174760, value = 10000 }, -- ms


  APS_shagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  APS_hiagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  APS_mhagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  APS_mlagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat
  APS_loagc_rtpdef = { val_list = { 0, 1 },
   		       	   value = 0 },
  --  0 = RTP ON, 1 = RTP Defeat



-- Synchronization (Smart Coupling) and other things

   APS_mbagc_sync = { min = -1000.0, max = 0.0, value = -1.4 }, -- dB

-- Gating

   APS_mbagc_glock_thresh = { min = -1000.0, max = 0.0, value = -15 }, -- dB

   APS_shagc_glock_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   APS_hiagc_glock_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   APS_mhagc_glock_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   APS_mlagc_glock_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB
   APS_loagc_glock_thresh_off = { min = -1000.0, max = 1000.0, value = 0.0 },
   -- dB

-- Time Constants

   APS_mbagc_release = { min = 1/1024, max = 1024, value = 1 }, -- unitless
   APS_shagc_rel_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_hiagc_rel_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_mhagc_rel_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_mlagc_rel_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_loagc_rel_cal = { min = 0, max = 174760, value = 10000 }, -- ms

   APS_mbagc_multf = {min = 0.0001, max = 1000, value = 100 }, -- unitless

   APS_mbagc_attack = { min = 1/1024, max = 1024, value = 0.095 }, -- unitless

   APS_shagc_att_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_hiagc_att_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_mhagc_att_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_mlagc_att_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   APS_loagc_att_cal = { min = 0, max = 174760, value = 10000 }, -- ms
   
   APS_shagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   APS_hiagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   APS_mhagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   APS_mlagc_makeup = { min = -120, max = 1, value = -7 }, --dB
   APS_loagc_makeup = { min = -120, max = 1, value = -7 }, --dB

   APS_shagc_att2_react = { min = 0.000001, max = 1, value = 0.0001 },
   --unitless
   APS_shagc_att2_dur = { min = 0.000001, max = 1, value = 0.0001 }, --unitless
   APS_hiagc_att2_react = { min = 0.000001, max = 1, value = 0.0001 }, 
   --unitless
   APS_hiagc_att2_dur = { min = 0.000001, max = 1, value = 0.0001 }, --unitless
   APS_mhagc_att2_react = { min = 0.000001, max = 1, value = 0.0007 }, 
   --unitless
   APS_mhagc_att2_dur = { min = 0.000001, max = 1, value = 0.0001 }, --unitless
   APS_mlagc_att2_react = { min = 0.000001, max = 1, value = 0.001 }, 
   --unitless
   APS_mlagc_att2_dur = { min = 0.000001, max = 1, value = 0.0001 }, --unitless
   APS_loagc_att2_react = { min = 0.000001, max = 1, value = 0.001 }, 
   --unitless
   APS_loagc_att2_dur = { min = 0.000001, max = 1, value = 0.0001 }, --unitless

   APS_shagc_att2_mat = { min = 0, max = 174760, value = 30 }, -- ms
   APS_hiagc_att2_mat = { min = 0, max = 174760, value = 30 }, -- ms
   APS_mhagc_att2_mat = { min = 0, max = 174760, value = 30 }, -- ms
   APS_mlagc_att2_mat = { min = 0, max = 174760, value = 50 }, -- ms
   APS_loagc_att2_mat = { min = 0, max = 174760, value = 75 }, -- ms

   APS_shagc_sat2_ll = { min = 0, max = 174760, value = 0 }, -- unitless
   APS_hiagc_sat2_ll = { min = 0, max = 174760, value = 0 }, -- unitless
   APS_mhagc_sat2_ll = { min = 0, max = 174760, value = 0 }, -- unitless
   APS_mlagc_sat2_ll = { min = 0, max = 174760, value = 0 }, -- unitless
   APS_loagc_sat2_ll = { min = 0, max = 174760, value = 0 }, -- unitless

   APS_shagc_rel2_speed = { min = 1, max = 4, value = 1.25 }, --unitless
   APS_hiagc_rel2_speed = { min = 1, max = 4, value = 1.25 }, --unitless
   APS_mhagc_rel2_speed = { min = 1, max = 4, value = 1.25 }, --unitless
   APS_mlagc_rel2_speed = { min = 1, max = 4, value = 1.25 }, --unitless
   APS_loagc_rel2_speed = { min = 1, max = 4, value = 1.25 }, --unitless

   APS_shagc_att2_thresh = { min = -1000.0, max = 120.0, value = 0.0 }, -- dB
   APS_hiagc_att2_thresh = { min = -1000.0, max = 120.0, value = 0.0 }, -- dB
   APS_mhagc_att2_thresh = { min = -1000.0, max = 120.0, value = 0.0 }, -- dB
   APS_mlagc_att2_thresh = { min = -1000.0, max = 120.0, value = 0.0 }, -- dB
   APS_loagc_att2_thresh = { min = -1000.0, max = 120.0, value = 5.1 }, -- dB

   APS_shagc_att2_lvl = { min = 0.0001, max = 30.0, value = 1 }, -- unitless
   APS_hiagc_att2_lvl = { min = 0.0001, max = 30.0, value = 1 }, -- unitless
   APS_mhagc_att2_lvl = { min = 0.0001, max = 30.0, value = 1 }, -- unitless
   APS_mlagc_att2_lvl = { min = 0.0001, max = 30.0, value = 1 }, -- unitless
   APS_loagc_att2_lvl = { min = 0.0001, max = 30.0, value = 1 }, -- unitless

   APS_shagc_gbgo = { min = 0.000001, max = 1, value = 1.0 }, --unitless
   APS_hiagc_gbgo = { min = 0.000001, max = 1, value = 1.0 }, --unitless
   APS_mhagc_gbgo = { min = 0.000001, max = 1, value = 1.0 }, --unitless

----------------------------------end mbagc-----------------------------------





----------------------------------enhancers-----------------------------------
   APS_hi_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_md_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_lo_gain = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hi_freq = { min = 10, max = 15000, value = 5000 }, --Hz
   APS_md_freq = { min = 10, max = 15000, value = 1000 }, --Hz
   APS_lo_freq = { min = 10, max = 15000, value = 80 }, --Hz
   APS_hi_q = { min = 0.001, max = 4, value = 1.0 }, -- q
   APS_md_q = { min = 0.001, max = 4, value = 1.0 }, -- q
   APS_lo_q = { min = 0.001, max = 4, value = 1.0 }, -- q



   APS_bass_enh = { min = -120, max = 12.0, value = 3.0 }, -- dB
   APS_bass_thunder = { min = -1000, max = 12, value = -100 }, -- dB
   APS_stereo_enh = { min = 0, max = 2.0, value = -12 }, --unitless
   APS_air_enh = { min = -120, max = 12.0, value = -120.0 }, --dB

   APS_wmb_thresh = { min = -120.0, max = -12.0, value = -5.0 }, --dB
   APS_wmb_smt = { min = 0.0, max = 1, value = 0 }, --unitless
   APS_phb_thresh = { min = -120.0, max = 12.0, value = 0.0 }, --dB
   APS_benh_sl = { val_list = { 12, 24 },
   		       	   value = 12 },
   -- 12 = 12dB-oct, 24 = 24dB -oct


-------------------------------Limiter Crossovers-----------------------------

   APS_sllim_xovr= { val_list = { 1, 2, 3 },
   		       	   value = 3 },
   -- 1 = 150Hz, 2 = 120Hz, 3 = 110Hz

   APS_lolim_xovr = { val_list = { 1, 2 },
   		       	   value = 2 },
   -- 1 = 420Hz, 2 = 330Hz


--------------------------------MB Limiters-----------------------------------

   APS_shlim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hilim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mhlim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mllim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_lolim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_sllim_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   APS_lim_drive = { min = -1000.0, max = 122.0, value = 0.0 }, -- dB

   APS_shlim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hilim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mhlim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mllim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_lolim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_sllim_drive_off = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
 
   APS_mhlim_dcomp = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hilim_dcomp = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   APS_shlim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   APS_hilim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   APS_mhlim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   APS_mllim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   APS_lolim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB
   APS_sllim_thresh = { min = -12.0, max = 20.0, value = 0.0 }, -- dB

   APS_lim_sidemast = { min = -1000.0, max = 122.0, value = 0.0 }, -- dB

   APS_shlim_scg = { min = -100.0, max = 100.0, value = 0.0, volatile=true }, 
   -- dB
   APS_hilim_scg = { min = -100.0, max = 100.0, value = 0.0, volatile=true }, 
   -- dB
   APS_mhlim_scg = { min = -100.0, max = 100.0, value = -2.0, volatile=true }, 
   -- dB
   APS_mllim_scg = { min = -100.0, max = 100.0, value = -2.5, volatile=true }, 
   -- dB
   APS_lolim_scg = { min = -100.0, max = 100.0, value = -2.0, volatile=true }, 
   -- dB
   APS_sllim_scg = { min = -100.0, max = 100.0, value = -2.0, volatile=true }, 
   -- dB

   APS_lim_release = { min = 1/1024, max = 1024, value = 1 }, -- unitless

   APS_shlim_rel_cal = { min = 0, max = 174760, value = 400 }, -- ms
   APS_hilim_rel_cal = { min = 0, max = 174760, value = 400 }, -- ms
   APS_mhlim_rel_cal = { min = 0, max = 174760, value = 400 }, -- ms
   APS_mllim_rel_cal = { min = 0, max = 174760, value = 400 }, -- ms
   APS_lolim_rel_cal = { min = 0, max = 174760, value = 400 }, -- ms
   APS_sllim_rel_cal = { min = 0, max = 174760, value = 400 }, -- ms


   APS_lim_attack = { min = 1/1024, max = 1024, value = 1 }, -- unitless

   APS_shlim_att_cal = { min = 0, max = 174760, value = 200 }, -- ms 
   APS_hilim_att_cal = { min = 0, max = 174760, value = 200 }, -- ms
   APS_mhlim_att_cal = { min = 0, max = 174760, value = 200 }, -- ms
   APS_mllim_att_cal = { min = 0, max = 174760, value = 200 }, -- ms
   APS_lolim_att_cal = { min = 0, max = 174760, value = 400 }, -- ms
   APS_sllim_att_cal = { min = 0, max = 174760, value = 800 }, -- ms

   APS_shlim_imt = { min = 0.001, max = 300, value = 0.6, volatile=true }, 
   -- unitless
   APS_hilim_imt = { min = 0.001, max = 300, value = 0.6, volatile=true }, 
   -- unitless
   APS_mhlim_imt = { min = 0.001, max = 300, value = 0.6, volatile=true }, 
   -- unitless
   APS_mllim_imt = { min = 0.001, max = 300, value = 0.6, volatile=true }, 
   -- unitless
   APS_lolim_imt = { min = 0.001, max = 300, value = 0.6, volatile=true }, 
   -- unitless
   APS_sllim_imt = { min = 0.001, max = 300, value = 0.6, volatile=true }, 
   -- unitless

-- APS_shlim_frel = { min = 0, max = 174760, value = 5, volatile=true }, -- ms
-- APS_hilim_frel = { min = 0, max = 174760, value = 5, volatile=true }, -- ms
-- APS_mhlim_frel = { min = 0, max = 174760, value = 5, volatile=true }, -- ms
-- APS_mllim_frel = { min = 0, max = 174760, value = 8, volatile=true }, -- ms
-- APS_lolim_frel = { min = 0, max = 174760, value = 10, volatile=true }, -- ms
-- APS_sllim_frel = { min = 0, max = 174760, value = 10, volatile=true }, -- ms

   APS_sllim_pkhis = { min = 0, max = 1024, value = 0.1, volatile=true }, 
   -- unitless 
   APS_lolim_pkhis = { min = 0, max = 1024, value = 0.1, volatile=true }, 
   -- unitless
   APS_mllim_pkhis = { min = 0, max = 1024, value = 0.1, volatile=true }, 
   -- unitless
   APS_mhlim_pkhis = { min = 0, max = 1024, value = 0.1, volatile=true }, 
   -- unitless
   APS_hilim_pkhis = { min = 0, max = 1024, value = 0.1, volatile=true }, 
   -- unitless
   APS_shlim_pkhis = { min = 0, max = 1024, value = 0.1, volatile=true }, 
   -- unitless

   APS_lim_glock_thresh = { min = -1000.0, max = 20.0, value = -26 }, -- dB

   APS_shlim_gate_thresh = { min = -1000.0, max = 100.0, value = 0.0 }, -- dB
   APS_hilim_gate_thresh = { min = -1000.0, max = 100.0, value = 0.0 }, -- dB
   APS_mhlim_gate_thresh = { min = -1000.0, max = 100.0, value = 0.0 }, -- dB
   APS_mllim_gate_thresh = { min = -1000.0, max = 100.0, value = 0.0 }, -- dB
   APS_lolim_gate_thresh = { min = -1000.0, max = 100.0, value = 0.0 }, -- dB
   APS_sllim_gate_thresh = { min = -1000.0, max = 100.0, value = 0.0 }, -- dB

   APS_sllim_sync = { min = -1000.0, max = 0.0, value = -12.0 }, -- dB

   APS_shlim_ratio = { min = 0.000001, max = 1, value = 0.5 }, -- unitless
   APS_hilim_ratio = { min = 0.000001, max = 1, value = 0.5 }, -- unitless
   APS_mhlim_ratio = { min = 0.000001, max = 1, value = 0.5 }, -- unitless
   APS_mllim_ratio = { min = 0.000001, max = 1, value = 0.5 }, -- unitless
   APS_lolim_ratio = { min = 0.000001, max = 1, value = 0.5 }, -- unitless
   APS_sllim_ratio = { min = 0.000001, max = 1, value = 0.5 }, -- unitless

   APS_shlim_imr = { min = -100, max = -1, value = -1, volatile=true }, 
   -- unitless
   APS_hilim_imr = { min = -100, max = -1, value = -1, volatile=true }, 
   -- unitless
   APS_mhlim_imr = { min = -100, max = -1, value = -1, volatile=true }, 
   -- unitless
   APS_mllim_imr = { min = -100, max = -1, value = -1, volatile=true }, 
   -- unitless
   APS_lolim_imr = { min = -100, max = -1, value = -1, volatile=true }, 
   -- unitless
   APS_sllim_imr = { min = -100, max = -1, value = -1, volatile=true }, 
   -- unitless
   
   APS_shlim_slowtc_at = { min = 0, max = 174760, value = 200, volatile=true }, 
   -- ms
   APS_hilim_slowtc_at = { min = 0, max = 174760, value = 200, volatile=true }, 
   -- ms
   APS_mhlim_slowtc_at = { min = 0, max = 174760, value = 180, volatile=true }, 
   -- ms
   APS_mllim_slowtc_at = { min = 0, max = 174760, value = 180, volatile=true }, 
   -- ms
   APS_lolim_slowtc_at = { min = 0, max = 174760, value = 150, volatile=true }, 
   -- ms
   APS_sllim_slowtc_at = { min = 0, max = 174760, value = 150, volatile=true }, 
   -- ms

--------------------------------HD Limiter Controls--------------------------

   APS_shlim_hd_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_hilim_hd_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mhlim_hd_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_mllim_hd_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_lolim_hd_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_sllim_hd_mix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB


------------------------------Front End Clipper System----------------------


   APS_clip_drive = { min = -120, max = 6.0, value = 0.0 }, --dB
   APS_clip_ofst = { min = -120, max = 20, value = 0.0 }, -- dB
   APS_bs412_rtrim = { min = 0, max = 5.0, value = 0.75 }, -- unitless
   APS_abc_thresh = { min = -20, max = 0.0, value = -20, volatile=true }, --dB
   APS_bc_dyn_sens = { min = -1000, max = 70, value = 40, volatile=true }, --dB
   APS_abc_ratio = { min = -5, max = 0.0, value = -1, volatile=true }, 
   -- unitless
   APS_as_drive = { min= -122, max = 1000.0,  value = 0 }, --dB
   APS_bc_dyn_ratio =  { min = -0.9, max = 0.0, value = -0.25}, 
   --bass waveform squareness
   APS_bc_dyn_thresh = { min = -120, max = 6.0, value = -8.0 }, --dB
   APS_abc_hithresh = {min = -100, max = 100, value = 4.5, volatile=true },--dB
   APS_abc_threshcal = { min = -120, max = 12.0, value = 0.5, volatile=true }, 
   --unitless
   APS_abc_hishelf = { min = -122, max = 12.0, value = 6, volatile = true }, 
   --dB
   APS_bc_style = { val_list = { 0, 1 }, value = 1 },
   -- 1 = auto threshold, 2 = fixed threshold 

   APS_bc_drive = { min = -120.0, max = 12.0, value = 0.0 }, --dB
   APS_w_bass_drive= { min = -120.0, max = 12.0, value = 0.0 }, --dB
   APS_bassclip_out_cal = { min = -122.0, max = 0.0, value = -22.5 }, --dB
   APS_bc_smooth = { min = 0.0001, max = 12.0, value = 5 }, --unitless
   APS_abc_rel = { min = 1, max = 100000, value = 10, volatile=true }, --ms
   APS_abc_att = { min = 1, max = 100000, value = 2, volatile=true }, --ms
   APS_as_patt = { min = 1, max = 100000, value = 700, volatile=true }, --ms
   APS_as_prel = { min = 1, max = 100000, value = 1, volatile=true }, --ms
   APS_as_fa = { min = 0, max = 174760, value = 180, volatile=true }, -- ms
   APS_as_fr = { min = 0, max = 174760, value = 2 }, -- ms
   APS_as_ownd = { min = -122, max = 40, value = 27, volatile=true }, --dB
   APS_as_thresh = { min = -122, max = 100000, value = -8, volatile=true },--dB
    APS_as_ratio1 = { min = -5, max = 0.0, value = -1.25, volatile=true }, 
   -- unitless
   APS_mono_gain = { min = -120, max = 0.0, value = -3.0 }, --dB
   APS_bc_fix_thresh = { min = -120, max = 12.0, value = -2.5 }, --dB
   APS_hdlim_drive = { min = -120, max = 12.0, value = -21.5 }, --dB
   APS_benh_mode =  { val_list = { 0, 1 },
   		       	   value = 0 },
   APS_thunder_hp = { val_list = { 0, 1 },
   		       	   value = 0 },
                   --  1 = engage, 0 = bypass
------------------------------System Params----------------------------------

   APS_agc_op_thresh = { min = -1000.0, max = 12.0, value = -4.4 }, -- dB
   APS_bc_fixed_cal = { min = -1000.0, max = 12.0, value = -10 }, -- dB
   APS_bassclip_cal = { min = -1000.0, max = 30.0, value = -3, volatile=true },
   -- dB 
   APS_lim_outcal = { min = -1000.0, max = 122.0, value = -60, volatile=true },
   -- dB
   APS_lim_incomp = { min = -1000.0, max = 50.0, value = -2 }, -- dB
   APS_lim_incalo = { min = -1000.0, max = 50.0, value = 8, volatile=true }, 
   -- dB
   APS_clipcal = { min = -1000.0, max = 12, value = 3.5, volatile=true }, -- dB
   APS_as_incal = { min = -1000.0, max = 12, value = -25.5 }, -- dB
   APS_as_outcal = { min = -1000.0, max = 100, value = 7, volatile=true }, 
   -- dB
   APS_stenh_sum_rel = { min = 0, max = 100000, value = 100 }, -- ms
   APS_stenh_dif_rel = { min = 0, max = 100000, value = 500 }, -- ms
   APS_stenh_dif_att = { min = 0, max = 100000, value = 35 }, -- ms
   APS_stenh_diff_mat = {min = -100, max = 2, value = 0.0 }, --dB
   APS_stenh_mono_det = {min = -1000, max = 20, value = -15, volatile=true }, -- dB
   APS_bass_enh_thresh = { min = 0, max = 100, value = 14}, -- unitless
   APS_bass_enh_ratio = { min = -100, max = 0.0, value = -1.0 }, -- unitless
   APS_bass_enh_scg = { min = -1000.0, max = 30.0, value = -10 }, -- dB
   APS_bass_enh_att = { min = 0, max = 174760, value = 250 }, -- ms
   APS_benh_rel = {min =  0, max = 100000, value = 700, volatile=true }, -- ms
   APS_benh_gate = {min = -1000, max = 20, value = -40, volatile=true }, -- dB
   APS_412thresh_ofst = { min = -122, max = 12.0, value = -11 }, -- dB
   APS_as412_cal = { min = -122, max = 12.0, value = -28 }, -- dB
   APS_bc_mtcal = { min = -122, max = 20.0, value = -8, volatile=true }, -- dB


--------------------------LL  Output Mix Controls------------------------------------
   APS_shagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   APS_hiagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   APS_mhagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   APS_mlagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   APS_loagc_djmix = { min = -1000.0, max = 12.0, value = 0 }, -- dB 
   APS_djcal = { min = -1000.0, max = 0.0, value = -20 }, -- dB  
   APS_dj_rngmast = { min = -1000.0, max = 12.0, value = -20 }, -- dB
   APS_dj_mdlimrng = { min = -1000.0, max = 12.0, value = 0 }, -- dB
   APS_dj_hilimrng = { min = -1000.0, max = 12.0, value = 0 }, -- dB
   APS_dj_lolimrng = { min = -1000.0, max = 12.0, value = 0 }, -- dB
   APS_djomast = { min = -1000.0, max = 12.0, value = -20 }, -- dB
   APS_djhimix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_djmdmix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_djlomix = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   APS_djhatt = { min = 0, max = 100000, value = 1 }, -- ms
   APS_djmatt = { min = 0, max = 100000, value = 1 }, -- ms
   APS_djlatt = { min = 0, max = 100000, value = 6 }, -- ms
   APS_djhrel = { min = 0, max = 100000, value = 10 }, -- ms
   APS_djmrel = { min = 0, max = 100000, value = 12 }, -- ms
   APS_djlrel = { min = 0, max = 100000, value = 18 }, -- ms
   APS_djhscg = { min = -1000.0, max = 20.0, value = -12 }, -- dB 
   APS_djhslk = { min = 0.000001, max = 2.5, value = 0.7 }, -- unitless
   APS_djmslk = { min = 0.000001, max = 2.5, value = 0.7 }, -- unitless
   APS_djlslk = { min = 0.000001, max = 2.5, value = 0.7 }, -- unitless
   APS_djocal = { min = -1000.0, max = 12.0, value = -8, volatile=true },-- dB
   APS_djlratio = { min = 0, max = 1.0, value = 1 }, -- unitless
   APS_djmratio = { min = 0, max = 1.0, value = 0.95 }, -- unitless
   APS_djhratio = { min = 0, max = 1.0, value = 0.9 }, -- unitless
   clipslk = { min = 1, max = 2.0, value = 2.0 }, -- unitless
   APS_djdrvcal = { min = -1000.0, max = 12.0, value = -25, volatile=true }, 
   -- dB
   APS_dj_cal = { min = -1000.0, max = 30.0, value = 0 }, -- dB 
   APS_dj_bclip = { min = -20, max = 12.0, value = -2 }, --dB
----------------------------- HD Section---------------------------------------

   HD_fnl_drive =  { min = -1000.0, max = 122.0, value = 0.0 }, -- dB
   HD_fnl_opt =  { min = -1000.0, max = 122.0, value = 0.0 }, -- dB
   HD_fnl_release =  { min = 0, max = 174760, value = 10000 }, -- ms
   HD_lntc_att = { min = 0, max = 100000, value = 1 }, -- unitless
   HD_lntc_rel = { min = 0, max = 100000, value = 0.5 }, -- unitless
   HD_pk_his = { min = 0, max = 1, value = 0.0001 }, -- unitless
   HD_pk_react = { min = 0, max = 1, value = 0.89999997615814 }, -- unitless
   HD_ftc_release = { min = 0, max = 174760, value = 80 }, -- ms
   HD_fnl_imsense = { min = 0.00001, max = 100, value = 0.1 }, -- unitless


   HD_hdbass_enhance =  { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   HD_phatbass = { min = -1000.0, max = 12.0, value = 0.0 }, -- dB
   HD_hd_bc_smooth =  { min = 1, max = 2, value = 0.0 }, -- dB
   HD_hd_bc_thresh =  { min = -1000.0, max = 12.0, value = 0.0 }, -- dB

   HD_sensus_sens =  { min = -1000.0, max = 122.0, value = 0.0 }, -- dB
   HD_sensus_freq =  { min = 1000, max = 20000, value = 20000 }, -- Hertz


---------------------------- Solar Plexus -----------------------------------

   spl_half_f_gain = { min = -1000, max = 0, value = -4.1 },  -- dB
   spl_level = { min = 0, max = 24, value = 0 }, -- dB of enhancement
   -- Note that the above works like a shelving EQ, so 0dB gives no effect.
   spl_engage = { val_list = { 0, 1 }, value = 0 }, -- 0 = bypass 1 = engage

---- test tone

   test_tone = { val_list = { 1, 2, 3, 4, 5 }, value = 1, volatile=true }, 
   ---- enumerated: 1 = normal operation, 2 = tone on L, 3 = tone on R,
   ----   4 = tone on L+R, 5 = tone on L-R
   ---- This variable is not saved (volatile) because we want to make a
   ---- test tone mode that stands apart from any preset or I/O config.
   tone_cal = { min = -1000, max = -12, value = -13.105, volatile=true }, -- dB

----------------- Removed Params - here to prevent GUI errors----------------

   APS_shagc_enh = { min = -120, max = 120.0, value = -120.0 }, --dB
   APS_hiagc_enh = { min = -120, max = 120.0, value = -120.0 }, --dB
   APS_mhagc_enh = { min = -120, max = 120.0, value = -120.0 }, --dB
   APS_mlagc_enh = { min = -120, max = 120.0, value = -120.0 }, --dB
   APS_loagc_enh = { min = -120, max = 120.0, value = -120.0 }, --dB
   APS_det = { min = -120, max = 120.0, value = -120.0 }, --dB

}

